@@ -1,8 +1,8 @@
 #!/usr/bin/perl
-# DocumentId:	$Id: emuga-target.pl,v 1.3 2002/03/18 12:57:23 ola Exp $
+# DocumentId:	$Id: emuga-target.pl,v 1.5 2003/01/24 08:10:10 ola Exp $
 # Author:	$Author: ola $
-# Date:		$Date: 2002/03/18 12:57:23 $
-# Version:	$Revision: 1.3 $
+# Date:		$Date: 2003/01/24 08:10:10 $
+# Version:	$Revision: 1.5 $
 # Summary:
 #	This script handles the structure modifications to allow you to
 #	have a read and write group at the same time. This is possible
@@ -507,6 +507,8 @@ sub modifyPermission($$) {
 # Note:		May fail hard.
 # Status:	TESTED, DONE
 # Changes:	
+#	2003-01-20 Ola Lundqvist <opal@debian.org>
+#		Made sure that moving is correct of old is symbolic link.
 #	2002-02-14 Ola Lundqvist <opal@debian.org>
 #               Wrote it.
 ###############################################################################
@@ -514,9 +516,25 @@ sub moveAndMaybeClean($$) {
     my ($o, $n) = @_;
     my $old = relative($o);
     my $new = relative($n);
-    action(! move($old, $new),
-	   "Move $old to $new.",
-	   2);
+    if ($new =~ /\//) {
+	my $tnew = $n;
+	$tnew =~ s/\/.*//;
+	$tnew = relative($tnew);
+	if (! -d "$tnew" ) {
+	    action(! mkdir($tnew, 0770),
+		   "Create $tnew for read permissions.",
+		   2);
+	}
+    }
+    my $mvold = $old;
+    if (-l $mvold) {
+	$mvold = relative(readlink $mvold);
+    }
+    if ($mvold != $new) {
+	action(! move($mvold, $new),
+	       "Move $mvold to $new.",
+	       2);
+    }
     if ($old =~ /\//) {
 	$old =~ s|/[^/]+$||;
 	pdebug(5, "Trying to clean $old.");
@@ -1034,3 +1052,66 @@ sub stringHash(%) {
     }
     return "$ret)";
 }
+
+=head1 NAME
+
+emuga-groupgen - Generate group information.
+
+=head1 USAGE
+
+emuga-target [options] target [ [options] target [...] ]
+
+=head1 DESCRIPTION
+
+Emuga target can help you to set up a target (directory or file) so that two
+groups have inpact on the permissions for it. You can specify one read group
+and one write group.
+
+=head1 OPTIONS
+
+  --dl nr | --debug-level nr
+	Debug level (for debugging).
+  --ql nr | --quit-level nr
+	Quit level (for debugging).
+  -N	Not nice (chown, chgrp for all groups).
+  -n    Nice (chown, chgrp only for the group owning the target), default.
+  -R	Do not run chmod, chgrp recursively.
+  -S	Do not change the sgid bit, see -s below.
+  -s	Change the sgid bit for the writegroup (default). This affects
+	recursive changes for writegroup and also recursive changes when
+        it is removed or replaced with a readgroup.
+  -r readgroup
+        The group defined here is the one that should have read
+	permission on the target (and possibly subtargets).
+  -w writegroup
+	The group that should have write permission to the target
+	(and possibly subtargets).
+  --fix
+	Fix problems that can be fixed automaticly (defult no).
+  --help
+	Print this help.
+
+target:
+  The target is a file or directory. To make it really usable directories are
+  preferred.
+    
+  If no read or write-group is specified it only prints the old
+  permissions of the target(s).  
+
+Observe that the created directory structure makes an AND operation of the
+read and write access. The write permission implies read access but you
+can restrict read access by not adding the user to the read group if you want
+to do that (the effect is that you will probably not get write access either).
+
+Setting a empty ("") read or write group will unset that group. Note that
+there is no way to unset a group. You have to specify new permissions.
+
+=head1 AUTHOR
+
+Ola Lundqvist <opal@debian.org>
+
+=head1 SEE ALSO
+
+emuga-grougen(1)
+
+=cut
